==> flyyfluttersdk-1.0.0%2B1.tar.gz: lib/helpers/EncryptedString.dart <==
import 'dart:convert';
import 'dart:io';

import 'package:encrypt/encrypt.dart' as encrypt;
import 'package:encrypt/encrypt.dart';
import 'package:flyyfluttersdk/Flyy.dart';
import 'package:flyyfluttersdk/helpers/FlyyUtility.dart';
import 'package:package_info/package_info.dart';

class EncryptedString {
  static Future<String> getJsonString(String key, String value) async {
    var jsonBody = {};
    PackageInfo packageInfo = await PackageInfo.fromPlatform();

    var deviceInfo = await FlyyUtility.getDeviceDetails();
    var gaid = await FlyyUtility.getGaid();
    var deviceInfoList = await FlyyUtility.getDeviceDetails();
    var connectionType = await FlyyUtility.getNetworkConnectionType();
    var publicIp = await FlyyUtility.getPublicIP();

    jsonBody["connection_type"] = connectionType;
    jsonBody["platform"] = Platform.isAndroid ? "Android" : "iOS";
    jsonBody["device_id"] = deviceInfo[2];
    jsonBody["android_id"] = deviceInfo[2];
    jsonBody["gaid"] = gaid;
    jsonBody["event_name"] = key != null ? key : null;
    jsonBody["event_value"] = value != null ? value : null;
    jsonBody["model"] = deviceInfo[0];
    jsonBody["manufacturer"] = deviceInfo[3];
    jsonBody["ip"] = publicIp;
    jsonBody["datetime"] = new DateTime.now().toString();
    jsonBody["package_name"] = packageInfo.packageName;
    jsonBody["application_version"] = packageInfo.version;
    jsonBody["sdk_version"] = packageInfo.buildNumber;
    jsonBody["ext_user_id"] = Flyy.EXT_USER_ID;

    return json.encode(jsonBody);
  }

  static Future<String> getEncryptedString(
      String keyPair, String valuePair) async {
    var jsonString = await getJsonString(keyPair, valuePair);

    final key = encrypt.Key.fromUtf8("7jA8XDfgpHaKIwKlTPC4AMGxRxQ9GapJ");
    final iv = IV.fromUtf8("MX0wpZv4dBNxXk23");

    final encrypter = Encrypter(AES(key, mode: AESMode.cbc));

    final encrypted = encrypter.encrypt(jsonString, iv: iv);
    final decrypted = encrypter.decrypt(encrypted, iv: iv);

    return encrypted.base64;
  }
}

==> flyyfluttersdk-1.0.1%2B1.tar.gz: lib/helpers/EncryptedString.dart <==
import 'dart:convert';
import 'dart:io';

import 'package:encrypt/encrypt.dart' as encrypt;
import 'package:encrypt/encrypt.dart';
import 'package:flyyfluttersdk/Flyy.dart';
import 'package:flyyfluttersdk/helpers/FlyyUtility.dart';
import 'package:package_info/package_info.dart';

class EncryptedString {
  FlyyUtility flyyUtility;
  
  Future<String> getJsonString(String key, String value) async {
    var jsonBody = {};
    PackageInfo packageInfo = await PackageInfo.fromPlatform();
    flyyUtility = new FlyyUtility();

    var deviceInfo = await flyyUtility.getDeviceDetails();
    var gaid = await flyyUtility.getGaid();
    var deviceInfoList = await flyyUtility.getDeviceDetails();
    var connectionType = await flyyUtility.getNetworkConnectionType();
    var publicIp = await flyyUtility.getPublicIP();

    jsonBody["connection_type"] = connectionType;
    jsonBody["platform"] = Platform.isAndroid ? "Android" : "iOS";
    jsonBody["device_id"] = deviceInfo[2];
    jsonBody["android_id"] = deviceInfo[2];
    jsonBody["gaid"] = gaid;
    jsonBody["event_name"] = key != null ? key : null;
    jsonBody["event_value"] = value != null ? value : null;
    jsonBody["model"] = deviceInfo[0];
    jsonBody["manufacturer"] = deviceInfo[3];
    jsonBody["ip"] = publicIp;
    jsonBody["datetime"] = new DateTime.now().toString();
    jsonBody["package_name"] = packageInfo.packageName;
    jsonBody["application_version"] = packageInfo.version;
    jsonBody["sdk_version"] = packageInfo.buildNumber;
    jsonBody["ext_user_id"] = Flyy.EXT_USER_ID;

    return json.encode(jsonBody);
  }

  Future<String> getEncryptedString(
      String keyPair, String valuePair) async {
    var jsonString = await getJsonString(keyPair, valuePair);

    final key = encrypt.Key.fromUtf8("7jA8XDfgpHaKIwKlTPC4AMGxRxQ9GapJ");
    final iv = IV.fromUtf8("MX0wpZv4dBNxXk23");

    final encrypter = Encrypter(AES(key, mode: AESMode.cbc));

    final encrypted = encrypter.encrypt(jsonString, iv: iv);
    final decrypted = encrypter.decrypt(encrypted, iv: iv);

    return encrypted.base64;
  }
}
